@@ -1,4 +1,4 @@
-## Copyright 2012-2014 Sebastian Gibb
+## Copyright 2012-2016 Sebastian Gibb
 ## <mail@sebastiangibb.de>
 ##
 ## This file is part of MALDIquant for R and related languages.
@@ -102,8 +102,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
   intensities <- .unlist(lapply(tmpPeakList, function(x)x@intensity))
 
   ## store original mass sample number/id
-  samples <- rep.int(seq_along(tmpPeakList),
-                     .unlist(lapply(tmpPeakList, length)))
+  samples <- rep.int(seq_along(tmpPeakList), lengths(tmpPeakList))
 
   ## sort values by mass
   s <- sort.int(mass, method="quick", index.return=TRUE)
@@ -157,12 +156,12 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
 
     if (!isNonInteractivePlot && !plotInteractive) {
       warning(sQuote("plot"), " is ", sQuote("TRUE"),
-              " but no non-interactive devices is available. ",
+              " but no non-interactive device is available. ",
               "Using pdf() to create a default one.")
       pdf(paper="a4r", width=12)
     } else if (dev.cur() == 1L && plotInteractive) {
       warning(sQuote("plot"), " is ", sQuote("TRUE"),
-              " but no interactive devices is available. ",
+              " but no interactive device is available. ",
               "Using dev.new() to create a default one.")
       dev.new()
     }
