@@ -16,24 +16,21 @@
 ## You should have received a copy of the GNU General Public License
 ## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
 
-isMassObjectList <- function(x) {
+.isMassObjectList <- function(x) {
   if (!is.list(x)) {
     return(FALSE)
   }
 
-  areMassObjects <- length(x) &&
-                    all(unname(vapply(x, isMassObject, logical(1))))
-  return(areMassObjects)
+  length(x) && all(unname(vapply(x, .isMassObject, logical(1L))))
 }
 
 .stopIfNotIsMassObjectList <- function(x) {
-  if (!isMassObjectList(x)) {
-    parentCall <- deparse(sys.call(-1))
+  if (!.isMassObjectList(x)) {
+    parentCall <- deparse(sys.call(-1L))
     stop(parentCall, " : ", sQuote(deparse(substitute(x))),
          " is no list of MALDIquant::AbstractMassObject objects!", call.=FALSE)
-    return(FALSE)
   }
-  return(TRUE)
+  TRUE
 }
 
 isMassSpectrumList <- function(x) {
@@ -41,19 +38,16 @@ isMassSpectrumList <- function(x) {
     return(FALSE)
   }
 
-  areMassSpectrumObjects <- length(x) &&
-                            all(unname(vapply(x, isMassSpectrum, logical(1))))
-  return(areMassSpectrumObjects)
+  length(x) && all(unname(vapply(x, isMassSpectrum, logical(1L))))
 }
 
 .stopIfNotIsMassSpectrumList <- function(x) {
   if (!isMassSpectrumList(x)) {
-    parentCall <- deparse(sys.call(-1))
+    parentCall <- deparse(sys.call(-1L))
     stop(parentCall, " : ", sQuote(deparse(substitute(x))),
          " is no list of MALDIquant::MassSpectrum objects!", call.=FALSE)
-    return(FALSE)
   }
-  return(TRUE)
+  TRUE
 }
 
 isMassPeaksList <- function(x) {
@@ -61,18 +55,14 @@ isMassPeaksList <- function(x) {
     return(FALSE)
   }
 
-  areMassPeaksObjects <- length(x) &&
-                         all(unname(vapply(x, isMassPeaks, logical(1))))
-  return(areMassPeaksObjects)
+  length(x) && all(unname(vapply(x, isMassPeaks, logical(1L))))
 }
 
 .stopIfNotIsMassPeaksList <- function(x) {
   if (!isMassPeaksList(x)) {
-    parentCall <- deparse(sys.call(-1))
+    parentCall <- deparse(sys.call(-1L))
     stop(parentCall, " : ", sQuote(deparse(substitute(x))),
          " is no list of MALDIquant::MassPeaks objects!", call.=FALSE)
-    return(FALSE)
   }
-  return(TRUE)
+  TRUE
 }
-
