@@ -19,7 +19,8 @@
 ## AbstractMassObject
 setMethod(f="plot",
           signature=signature(x="AbstractMassObject", y="missing"),
-          definition=function(x, col="black", xlab="mass", ylab="intensity",
+          definition=function(x, col="black",
+                              xlab=expression(italic(m/z)), ylab="intensity",
                               type=ifelse(isMassPeaks(x), "h", "l"),
                               xlim=c(ifelse(length(x@mass),
                                             min(x@mass, na.rm=TRUE), 0L),
@@ -33,7 +34,8 @@ setMethod(f="plot",
                               abline.col="#808080", ...) {
 
   if (all(sub == x@metaData$file) && length(x@metaData$file) > 1L) {
-    sub <- paste0("merged ", ifelse(isMassSpectrum(x), "spectrum", "peaks"),
+    sub <- paste0(ifelse(isMassSpectrum(x),
+                         "averaged spectrum", "merged peaks"),
                   " composed of ", length(x@metaData$file), " ",
                   ifelse(isMassSpectrum(x), "MassSpectrum", "MassPeaks"),
                   " objects")
@@ -44,4 +46,3 @@ setMethod(f="plot",
        col.sub=col.sub, ...)
   abline(h=0L, col=abline.col)
 })
-
